==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/outputs/AgentPoolProvisioningStatusResponseProvisioningStatus.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Contains Provisioning errors
 * @property error
 * @property operationId
 * @property phase Phase represents the current phase of cluster actuation. E.g. Pending, Running, Terminating, Failed etc.
 * @property status
 */
public data class AgentPoolProvisioningStatusResponseProvisioningStatus(
    public val error: AgentPoolProvisioningStatusResponseError? = null,
    public val operationId: String? = null,
    public val phase: String? = null,
    public val status: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.hybridcontainerservice.outputs.AgentPoolProvisioningStatusResponseProvisioningStatus):
            AgentPoolProvisioningStatusResponseProvisioningStatus =
            AgentPoolProvisioningStatusResponseProvisioningStatus(
                error = javaType.error().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.hybridcontainerservice.kotlin.outputs.AgentPoolProvisioningStatusResponseError.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                operationId = javaType.operationId().map({ args0 -> args0 }).orElse(null),
                phase = javaType.phase().map({ args0 -> args0 }).orElse(null),
                status = javaType.status().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/outputs/AgentPoolProvisioningStatusResponseProvisioningStatus.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Contains Provisioning errors
 * @property error
 * @property operationId
 * @property phase Phase represents the current phase of cluster actuation. E.g. Pending, Running, Terminating, Failed etc.
 * @property status
 */
public data class AgentPoolProvisioningStatusResponseProvisioningStatus(
    public val error: AgentPoolProvisioningStatusResponseError? = null,
    public val operationId: String? = null,
    public val phase: String? = null,
    public val status: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.hybridcontainerservice.outputs.AgentPoolProvisioningStatusResponseProvisioningStatus): AgentPoolProvisioningStatusResponseProvisioningStatus =
            AgentPoolProvisioningStatusResponseProvisioningStatus(
                error = javaType.error().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.hybridcontainerservice.kotlin.outputs.AgentPoolProvisioningStatusResponseError.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                operationId = javaType.operationId().map({ args0 -> args0 }).orElse(null),
                phase = javaType.phase().map({ args0 -> args0 }).orElse(null),
                status = javaType.status().map({ args0 -> args0 }).orElse(null),
            )
    }
}
